import logging
import subprocess
import os
import os.path
import pathlib
import yaml
from wolkstack.utils import constants


def getCurrentDirectory():
    return os.getcwd()


def getProjectDirectory():
    return str(pathlib.Path(__file__).parents[1].absolute())


def createSubDirectory(subDirectory):
    return getProjectDirectory + subDirectory


def createCommandString(commandList):
    return " ".join(commandList)


def searchParentDirectoriesForFile(filename):
    file_name = filename  # file to be searched
    cur_dir = os.getcwd()  # Dir from where search starts can be replaced with any path

    while True:
        file_list = os.listdir(cur_dir)
        parent_dir = os.path.dirname(cur_dir)
        if file_name in file_list:
            return cur_dir
        else:
            if cur_dir == parent_dir:  # if dir is root dir
                logging.error(
                    """Can't find a suitable configuration file are you in the right directory?""")
                quit()
                break
            else:
                cur_dir = parent_dir


def handleExternalDNS(parentDir, outputYaml):
    result = callCommand(["terraform", "output", "external-dns-role-arn"],
                         cwd=parentDir + "/" + constants.TERRAFORM_PATH, stdout=True)
    logging.debug(f'Command result: ${str(result.stdout, "utf-8")}')
    file = open(outputYaml, 'r')
    data = yaml.safe_load(file)

    data["external-dns"]["serviceAccount"]["annotations"][
        "eks.amazonaws.com/role-arn"] = str(result.stdout, "utf-8").strip('\n')

    with open(outputYaml, 'w') as yaml_file:
        yaml.dump(data, yaml_file)


def callCommand(command, shell=False, cwd=None, stdout=False):
    logging.info(f'Running command: {command}')
    if shell:
        commandList = createCommandString(command)
    else:
        commandList = command
    result = subprocess.run(args=commandList, shell=shell,
                            cwd=cwd, stdout=subprocess.PIPE if stdout else None)
    logging.debug(f'Command result: {result}')
    return result



import sys
import os
import click
import time
import json
from .groups import groups
from cookiecutter.main import cookiecutter
from wolkstack.utils.helpers import handleExternalDNS, getProjectDirectory, searchParentDirectoriesForFile, callCommand
from wolkstack.utils import constants
import logging

logging.basicConfig(filename='logfile.log',
                    level=logging.DEBUG)
root = logging.getLogger()
root.setLevel(logging.DEBUG)

handler = logging.StreamHandler(sys.stdout)
handler.setLevel(logging.DEBUG)
formatter = logging.Formatter(
    '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
handler.setFormatter(formatter)
root.addHandler(handler)


# Main CLI Group
@click.group()
@click.version_option("1.1.1")
def main():
    """A framework for blazing fast cloud infrastructure management and deployment."""
    pass


@main.command(name='generate', help='Generate a project boilerplate for deployment.')
@click.option('-p', '--project-name', prompt=True)
@click.option('-e', '--email', prompt=True)
@click.option('-d', '--domain-name', prompt=True)
@click.option('-r', '--route-53-hosted-zone-id', prompt=True)
@click.option('-do', '--docker-hub-username', prompt=True)
@click.option('-gu', '--github-username', prompt=True)
@click.option('-gr', '--github-repository-name', prompt=True)
def generate_project(project_name, email, domain_name, route_53_hosted_zone_id,
                     docker_hub_username, github_username, github_repository_name):
    cookiecutter(getProjectDirectory() + "/templates/base",
                 no_input=True, extra_context=locals())


@main.command(name='update-containers', help='Manually update containers in case of CICD errors.')
def update_containers():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")
    callCommand(["bash", "predeploy.sh"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


@main.command(name='up', help='Create infrastructure and boot application.')
def deploy_project():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")

    callCommand(["bash", "deploy.sh"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)
    handleExternalDNS(directory, (directory + "/" +
                                  constants.HELM_TOOLS_PATH + "/values.yaml"))
    callCommand(["helm", "install", "deploy-tools", "../helm/toolChart"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)
    time.sleep(30)
    callCommand(["helm", "install", "wolkstack-apps", "../helm/appChart"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


@main.command(name='down', help='Delete infrastructure and tear down application.')
def teardown_project():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")

    callCommand(["helm", "uninstall", "deploy-tools"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)
    callCommand(["helm", "uninstall", "wolkstack-apps"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)
    callCommand(["bash", "destroy.sh"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


# Add groups
for group in groups:
    main.add_command(group)

# Initialize CLI
if __name__ == '__main__':
    args = sys.argv
    if "--help" in args or len(args) == 1:
        print("CVE")
    main()



import click
from wolkstack.utils.helpers import getProjectDirectory, searchParentDirectoriesForFile, callCommand
from wolkstack.utils import constants
import logging

# Command Group
@click.group(name='cluster')
def cluster():
    """Manage the deployed kubernetes cluster."""
    pass


@cluster.command(name='pods', help='get the pods in the Wolkstack cluster')
def pods_cmd():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")
    callCommand(["kubectl", "get", "pods", "-A"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


@cluster.command(name='services', help='get the services in the Wolkstack cluster')
def servies_cmd():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")
    callCommand(["kubectl", "get", "pods", "-A"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


@cluster.command(name='ingress', help='get the ingress in the Wolkstack cluster')
def ingress_cmd():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")
    callCommand(["kubectl", "get", "ingress"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


@cluster.command(name='cert', help='get the certificates in the Wolkstack cluster')
def cert_cmd():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")
    callCommand(["kubectl", "get", "certificate", "-A"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


@cluster.command(name='cert-manager', help='get the status of cert manager')
def cert_manager_cmd():
    directory = searchParentDirectoriesForFile("wolkstack.json")
    if directory:
        try:
            print(directory+"/wolkstack.json")
            open(directory + "/wolkstack.json",)
        except:
            logging.debug("Corrupt wolkstack.json file")
    callCommand(["kubectl", "describe", "certificate", "wolkstack-deployment-secret"], cwd=directory +
                "/" + constants.TERRAFORM_PATH)


if __name__ == '__main__':
    cluster()



from setuptools import setup, find_packages
from io import open
from os import path

import pathlib
# The directory containing this file
HERE = pathlib.Path(__file__).parent  # The text of the README file

README = (HERE / "README.md").read_text()

# automatically captured required modules for install_requires in requirements.txt and as well as configure dependency links
with open(path.join(HERE, 'requirements.txt'), encoding='utf-8') as f:
    all_reqs = f.read().split('\n')

install_requires = [x.strip() for x in all_reqs if ('git+' not in x)
                    and (
    not x.startswith('#')) and (not x.startswith('-'))]

dependency_links = [x.strip().replace('git+', '') for x in all_reqs
                    if 'git+' not in x]

setup(
    name='Wolkstack',
    description='A Framework for blazing fast cloud infrastructure management and deployment',
    packages=find_packages(),
    version='1.1.1',
    install_requires=install_requires,
    python_requires='>=3.7',
    entry_points='''
        [console_scripts]
        wolkstack=wolkstack.cli.main:main
    ''',
    author='Josh Gorman',
    keyword='infrastructure, deployment, aws, wolkstack, cloud',
    long_description=README,
    long_description_content_type='text/markdown',
    license='MIT',
    url="https://github.com/liannus/wolkstack",
    dependency_links=dependency_links,
    author_email='josh-gorman@hotmail.com',
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ]
)
